@@ -11,6 +11,10 @@ from .rules import Meta_Rule
 from .debug import Debug_Mode
 from .help import help_message
 
+from humpack import AbortTransaction
+
+#
+
 import os
 __info__ = {'__file__':os.path.join(os.path.abspath(os.path.dirname(__file__)), '_info.py')}
 with open(os.path.join(os.path.abspath(os.path.dirname(__file__)), '_info.py'), 'r') as f:
